@@ -677,12 +677,12 @@ impl DynamicIndexingSample {
 
         self.index_count = (INDEX_DATA_SIZE / size_of::<u32>()).0 as u32;
 
-        self.index_buffer_view = Some(IndexBufferView::new(
-            &index_buffer,
-            // ToDo: we need another constructor that would take Bytes
-            self.index_count,
-            Bytes::from(size_of::<u32>()),
-        ));
+        self.index_buffer_view = Some(
+            IndexBufferView::default()
+                .set_buffer_location(index_buffer.get_gpu_virtual_address())
+                .set_size_in_bytes(self.index_count * Bytes(4))
+                .set_format(Format::R32_UInt),
+        );
 
         self.index_buffer = Some(index_buffer);
         self.index_staging_buffer = Some(index_staging_buffer);
@@ -1010,7 +1010,7 @@ impl DynamicIndexingSample {
                     .set_resource(
                         &self.render_targets[self.frame_index as usize],
                     )
-                    .set_state_before(ResourceStates::CommonOrPresent)
+                    .set_state_before(ResourceStates::Common)
                     .set_state_after(ResourceStates::RenderTarget),
             )]);
 
@@ -1077,7 +1077,7 @@ impl DynamicIndexingSample {
                         &self.render_targets[self.frame_index as usize],
                     )
                     .set_state_before(ResourceStates::RenderTarget)
-                    .set_state_after(ResourceStates::CommonOrPresent),
+                    .set_state_after(ResourceStates::Common),
             )]);
 
         self.command_list
@@ -1192,11 +1192,10 @@ fn create_pipeline_state(
     let vs_bytecode = ShaderBytecode::from_bytes(&vertex_shader);
     let ps_bytecode = ShaderBytecode::from_bytes(&pixel_shader);
 
-    let input_layout = InputLayoutDesc::default().from_input_elements(&input_layout);
+    let input_layout =
+        InputLayoutDesc::default().from_input_elements(&input_layout);
     let pso_desc = GraphicsPipelineStateDesc::default()
-        .set_input_layout(
-            &input_layout,
-        )
+        .set_input_layout(&input_layout)
         .set_root_signature(root_signature)
         .set_vs_bytecode(&vs_bytecode)
         .set_ps_bytecode(&ps_bytecode)
@@ -1239,10 +1238,10 @@ cbuffer cb0 : register(b0)
 PSInput VSMain(VSInput input)
 {
     PSInput result;
-    
+
     result.position = mul(float4(input.position, 1.0f), g_mWorldViewProj);
     result.uv = input.uv;
-    
+
     return result;
 }
 #",
@@ -1333,24 +1332,23 @@ d3dx12.h as a dependency to have X12SerializeVersionedRootSignature"
             .set_flags(DescriptorRangeFlags::DataStatic),
     ];
 
+    let srv_table = RootDescriptorTable::default()
+        .set_descriptor_ranges(slice::from_ref(&ranges[0]));
+    let sampler_table = RootDescriptorTable::default()
+        .set_descriptor_ranges(slice::from_ref(&ranges[1]));
+
+    let cbv_table = RootDescriptorTable::default()
+        .set_descriptor_ranges(slice::from_ref(&ranges[2]));
+
     let root_parameters = vec![
         RootParameter::default()
-            .new_descriptor_table(
-                &RootDescriptorTable::default()
-                    .set_descriptor_ranges(slice::from_ref(&ranges[0])),
-            )
+            .new_descriptor_table(&srv_table)
             .set_shader_visibility(ShaderVisibility::Pixel),
         RootParameter::default()
-            .new_descriptor_table(
-                &RootDescriptorTable::default()
-                    .set_descriptor_ranges(slice::from_ref(&ranges[1])),
-            )
+            .new_descriptor_table(&sampler_table)
             .set_shader_visibility(ShaderVisibility::Pixel),
         RootParameter::default()
-            .new_descriptor_table(
-                &RootDescriptorTable::default()
-                    .set_descriptor_ranges(slice::from_ref(&ranges[2])),
-            )
+            .new_descriptor_table(&cbv_table)
             .set_shader_visibility(ShaderVisibility::Vertex),
         RootParameter::default()
             .set_shader_visibility(ShaderVisibility::Pixel)
@@ -1394,7 +1392,7 @@ fn setup_heaps(
     let rtv_heap = device
         .create_descriptor_heap(
             &DescriptorHeapDesc::default()
-                .set_heap_type(DescriptorHeapType::RTV)
+                .set_heap_type(DescriptorHeapType::Rtv)
                 .set_num_descriptors(FRAMES_IN_FLIGHT),
         )
         .expect("Cannot create RTV heap");
@@ -1405,7 +1403,7 @@ fn setup_heaps(
     let dsv_heap = device
         .create_descriptor_heap(
             &DescriptorHeapDesc::default()
-                .set_heap_type(DescriptorHeapType::DSV)
+                .set_heap_type(DescriptorHeapType::Dsv)
                 .set_num_descriptors(1),
         )
         .expect("Cannot create RTV heap");
@@ -1416,7 +1414,7 @@ fn setup_heaps(
     let cbv_srv_heap = device
         .create_descriptor_heap(
             &DescriptorHeapDesc::default()
-                .set_heap_type(DescriptorHeapType::CBV_SRV_UAV)
+                .set_heap_type(DescriptorHeapType::CbvSrvUav)
                 .set_flags(DescriptorHeapFlags::ShaderVisible)
                 .set_num_descriptors(u32::from(
                     FRAMES_IN_FLIGHT * CITY_ROW_COUNT * CITY_COLUMN_COUNT
