@@ -677,12 +677,12 @@ impl DynamicIndexingSample {
 
         self.index_count = (INDEX_DATA_SIZE / size_of::<u32>()).0 as u32;
 
-        self.index_buffer_view = Some(IndexBufferView::new(
-            &index_buffer,
-            // ToDo: we need another constructor that would take Bytes
-            self.index_count,
-            Bytes::from(size_of::<u32>()),
-        ));
+        self.index_buffer_view = Some(
+            IndexBufferView::default()
+                .set_buffer_location(index_buffer.get_gpu_virtual_address())
+                .set_size_in_bytes(self.index_count * Bytes(4))
+                .set_format(Format::R32_UInt),
+        );
 
         self.index_buffer = Some(index_buffer);
         self.index_staging_buffer = Some(index_staging_buffer);
@@ -1016,7 +1016,7 @@ impl DynamicIndexingSample {
                     .set_resource(
                         &self.render_targets[self.frame_index as usize],
                     )
-                    .set_state_before(ResourceStates::CommonOrPresent)
+                    .set_state_before(ResourceStates::Common)
                     .set_state_after(ResourceStates::RenderTarget),
             )]);
 
@@ -1083,7 +1083,7 @@ impl DynamicIndexingSample {
                         &self.render_targets[self.frame_index as usize],
                     )
                     .set_state_before(ResourceStates::RenderTarget)
-                    .set_state_after(ResourceStates::CommonOrPresent),
+                    .set_state_after(ResourceStates::Common),
             )]);
 
         self.command_list
@@ -1317,18 +1317,17 @@ d3dx12.h as a dependency to have DX12SerializeVersionedRootSignature"
             .set_flags(DescriptorRangeFlags::DataStatic),
     ];
 
+    let srv_table = RootDescriptorTable::default()
+        .set_descriptor_ranges(slice::from_ref(&ranges[0]));
+
+    let cbv_table = RootDescriptorTable::default()
+        .set_descriptor_ranges(slice::from_ref(&ranges[1]));
     let root_parameters = vec![
         RootParameter::default()
-            .new_descriptor_table(
-                &RootDescriptorTable::default()
-                    .set_descriptor_ranges(slice::from_ref(&ranges[0])),
-            )
+            .new_descriptor_table(&srv_table)
             .set_shader_visibility(ShaderVisibility::Pixel),
         RootParameter::default()
-            .new_descriptor_table(
-                &RootDescriptorTable::default()
-                    .set_descriptor_ranges(slice::from_ref(&ranges[1])),
-            )
+            .new_descriptor_table(&cbv_table)
             .set_shader_visibility(ShaderVisibility::Vertex),
         RootParameter::default()
             .set_shader_visibility(ShaderVisibility::Pixel)
@@ -1375,7 +1374,7 @@ fn setup_heaps(
     let rtv_heap = device
         .create_descriptor_heap(
             &DescriptorHeapDesc::default()
-                .set_heap_type(DescriptorHeapType::RTV)
+                .set_heap_type(DescriptorHeapType::Rtv)
                 .set_num_descriptors(FRAMES_IN_FLIGHT.into()),
         )
         .expect("Cannot create RTV heap");
@@ -1386,7 +1385,7 @@ fn setup_heaps(
     let dsv_heap = device
         .create_descriptor_heap(
             &DescriptorHeapDesc::default()
-                .set_heap_type(DescriptorHeapType::DSV)
+                .set_heap_type(DescriptorHeapType::Dsv)
                 .set_num_descriptors(1),
         )
         .expect("Cannot create RTV heap");
@@ -1397,7 +1396,7 @@ fn setup_heaps(
     let cbv_srv_heap = device
         .create_descriptor_heap(
             &DescriptorHeapDesc::default()
-                .set_heap_type(DescriptorHeapType::CBV_SRV_UAV)
+                .set_heap_type(DescriptorHeapType::CbvSrvUav)
                 .set_flags(DescriptorHeapFlags::ShaderVisible)
                 .set_num_descriptors(u32::from(
                     FRAMES_IN_FLIGHT * CITY_ROW_COUNT * CITY_COLUMN_COUNT
