@@ -426,7 +426,7 @@ impl HelloTextureSample {
                     .set_resource(
                         &self.render_targets[self.frame_index as usize],
                     )
-                    .set_state_before(ResourceStates::CommonOrPresent)
+                    .set_state_before(ResourceStates::Common)
                     .set_state_after(ResourceStates::RenderTarget),
             ),
         ]);
@@ -462,7 +462,7 @@ impl HelloTextureSample {
                         &self.render_targets[self.frame_index as usize],
                     )
                     .set_state_before(ResourceStates::RenderTarget)
-                    .set_state_after(ResourceStates::CommonOrPresent),
+                    .set_state_after(ResourceStates::Common),
             )]);
 
         PIXSupport::end_event_cmd_list(&self.command_list);
@@ -617,10 +617,10 @@ d3dx12.h as a dependency to have X12SerializeVersionedRootSignature"
         .set_num_descriptors(1)
         .set_flags(DescriptorRangeFlags::DataStatic)];
 
+    let descriptor_table =
+        RootDescriptorTable::default().set_descriptor_ranges(&ranges);
     let root_parameters = vec![RootParameter::default()
-        .new_descriptor_table(
-            &RootDescriptorTable::default().set_descriptor_ranges(&ranges),
-        )
+        .new_descriptor_table(&descriptor_table)
         .set_shader_visibility(ShaderVisibility::Pixel)];
 
     let sampler_desc = StaticSamplerDesc::default()
@@ -636,7 +636,7 @@ d3dx12.h as a dependency to have X12SerializeVersionedRootSignature"
         .set_desc_1_1(
             &RootSignatureDesc::default()
                 .set_parameters(&root_parameters)
-                .set_static_samplers(&vec![sampler_desc])
+                .set_static_samplers(std::slice::from_ref(&sampler_desc))
                 .set_flags(RootSignatureFlags::AllowInputAssemblerInputLayout),
         );
 
@@ -664,7 +664,7 @@ fn setup_heaps(
     let rtv_heap = device
         .create_descriptor_heap(
             &DescriptorHeapDesc::default()
-                .set_heap_type(DescriptorHeapType::RTV)
+                .set_heap_type(DescriptorHeapType::Rtv)
                 .set_num_descriptors(FRAMES_IN_FLIGHT),
         )
         .expect("Cannot create RTV heap");
@@ -675,7 +675,7 @@ fn setup_heaps(
     let srv_heap = device
         .create_descriptor_heap(
             &DescriptorHeapDesc::default()
-                .set_heap_type(DescriptorHeapType::CBV_SRV_UAV)
+                .set_heap_type(DescriptorHeapType::CbvSrvUav)
                 .set_flags(DescriptorHeapFlags::ShaderVisible)
                 .set_num_descriptors(1),
         )
