@@ -1,7 +1,9 @@
 use log::{debug, error, info, trace, warn};
-use winapi::shared::winerror;
 
-use crate::{DXError, DxResult};
+#[cfg(feature = "serde")]
+use serde::{Deserialize, Serialize};
+
+use crate::{DxError, DxResult};
 
 // ToDo: impl iterators
 
@@ -53,7 +55,8 @@ macro_rules! impl_mul_div {
 
 /// Bytes
 
-#[derive(Copy, Clone, Debug)]
+#[derive(PartialEq, Eq, Hash, Debug, Copy, Clone)]
+#[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
 pub struct Bytes(pub u64);
 
 // Bytes + Bytes = Bytes
@@ -175,7 +178,7 @@ pub fn compile_shader(
         }
         Err(error) => {
             error!("Cannot compile shader: {}", &error);
-            Err(DXError::new(
+            Err(DxError::new(
                 "compile_hlsl",
                 winapi::shared::winerror::E_FAIL,
             ))
